@@ -208,6 +208,8 @@ class ConfigDialog(QtGui.QDialog):
         self.orderrois = False
         #: (:obj:`bool`) security stream enabled
         self.secstream = False
+        #: (:obj:`bool`) map image sources to color channels
+        self.imagechannels = False
         #: (:obj:`str`) security stream port
         self.secport = "5657"
         #: (:obj:`str`) hidra data port
@@ -242,9 +244,13 @@ class ConfigDialog(QtGui.QDialog):
         self.zeromask = False
         #: (:obj:`bool`) nan mask enabled
         self.nanmask = True
+        #: (:obj:`bool`) adding maximal type value to negative high value mask
+        self.negmask = False
 
         #: (:obj:`bool`) show bakcground subtraction widget
         self.showsub = True
+        #: (:obj:`bool`) show bakcground subtraction scaling widget
+        self.showsubsf = False
         #: (:obj:`bool`) show transformation widget
         self.showtrans = True
         #: (:obj:`bool`) show memory buffer widget
@@ -272,11 +278,24 @@ class ConfigDialog(QtGui.QDialog):
         self.autodownsample = False
         #: (:obj:`bool`) keep original coordinates
         self.keepcoords = False
+        #: (:obj:`bool`) accelerate buffer sum
+        self.accelbuffersum = False
         #: (:obj:`bool`) lazy image slider
         self.lazyimageslider = True
         #: (:obj:`bool`) crosshair locker switched on
         self.crosshairlocker = True
 
+        #: (:obj:`str`) asapo server
+        self.asaposerver = ""
+        #: (:obj:`str`) asapo token
+        self.asapotoken = ""
+        #: (:obj:`str`) asapo beamtime id
+        self.asapobeamtime = ""
+        #: (:obj:`str`) asapo sourcepath
+        self.asaposourcepath = ""
+        #: (:obj:`list` < :obj:`str` > ) asapo datasources
+        self.asapodatasources = []
+
         #: (:obj:`str`) json hidra detector server list
         self.detservers = "[]"
         #: (:obj:`bool`) use default detector servers
@@ -344,6 +363,14 @@ class ConfigDialog(QtGui.QDialog):
         self.showallrois = False
         #: (:obj:`bool`) send rois to LavueController flag
         self.sendrois = False
+        #: (:obj:`bool`) send results to LavueController flag
+        self.sendresults = False
+        #: (:obj:`bool`) set roi1, roi2, roi3, ... when alias names are missing
+        self.singlerois = False
+        #: (:obj:`int`) number of points for diffractogram
+        self.diffnpt = 1000
+        #: (:obj:`bool`) correct solid angle flag
+        self.correctsolidangle = True
         #: (:obj:`bool`) store display parameters for specific sources
         self.sourcedisplay = False
         #: (:obj:`dict` <:obj: `str`, :obj: `str` >) object title dictionary
@@ -402,21 +429,25 @@ class ConfigDialog(QtGui.QDialog):
         """
         self.__ui.rateDoubleSpinBox.setValue(self.refreshrate)
         self.__ui.nrsourcesSpinBox.setValue(self.nrsources)
+        self.__ui.diffsizeSpinBox.setValue(self.diffnpt)
         self.__ui.toolrefreshtimeDoubleSpinBox.setValue(self.toolrefreshtime)
         self.__ui.pollingintervalDoubleSpinBox.setValue(
             self.toolpollinginterval)
         self.__ui.aspectlockedCheckBox.setChecked(self.aspectlocked)
         self.__ui.downsampleCheckBox.setChecked(self.autodownsample)
         self.__ui.keepCoordsCheckBox.setChecked(self.keepcoords)
+        self.__ui.buffersumCheckBox.setChecked(self.accelbuffersum)
         self.__ui.lazyimageCheckBox.setChecked(self.lazyimageslider)
         self.__ui.statsscaleCheckBox.setChecked(not self.statswoscaling)
         self.__ui.sardanaCheckBox.setChecked(self.sardana)
         self.__ui.doorLineEdit.setText(self.door)
         self.__ui.addroisCheckBox.setChecked(self.addrois)
         self.__ui.orderroisCheckBox.setChecked(self.orderrois)
+        self.__ui.imagechannelsCheckBox.setChecked(self.imagechannels)
         self.__ui.secstreamCheckBox.setChecked(self.secstream)
         self.__ui.zeromaskCheckBox.setChecked(self.zeromask)
         self.__ui.nanmaskCheckBox.setChecked(self.nanmask)
+        self.__ui.negmaskCheckBox.setChecked(self.negmask)
         self.__ui.secautoportCheckBox.setChecked(self.secautoport)
         self.__ui.secportLineEdit.setText(self.secport)
         self.__ui.hidraportLineEdit.setText(self.hidraport)
@@ -429,6 +460,7 @@ class ConfigDialog(QtGui.QDialog):
         self.__ui.showstepsCheckBox.setChecked(self.showsteps)
         self.__ui.calcvarianceCheckBox.setChecked(self.calcvariance)
         self.__ui.showsubCheckBox.setChecked(self.showsub)
+        self.__ui.showsubsfCheckBox.setChecked(self.showsubsf)
         self.__ui.showtransCheckBox.setChecked(self.showtrans)
         self.__ui.showmbufferCheckBox.setChecked(self.showmbuffer)
         self.__ui.showrangeCheckBox.setChecked(self.showrange)
@@ -438,8 +470,14 @@ class ConfigDialog(QtGui.QDialog):
         self.__ui.showframerateCheckBox.setChecked(self.showframerate)
         self.__ui.timeoutLineEdit.setText(str(self.timeout))
         self.__ui.zmqtopicsLineEdit.setText(" ".join(self.zmqtopics))
+        self.__ui.asapodatasourcesLineEdit.setText(
+            " ".join(self.asapodatasources))
         self.__ui.detserversLineEdit.setText(
             " ".join(json.loads(self.detservers)))
+        self.__ui.asaposerverLineEdit.setText(self.asaposerver)
+        self.__ui.asapotokenLineEdit.setText(self.asapotoken)
+        self.__ui.asapobeamtimeLineEdit.setText(self.asapobeamtime)
+        self.__ui.asaposourcepathLineEdit.setText(self.asaposourcepath)
         self.__ui.defdetserversCheckBox.setChecked(self.defdetservers)
         self.__ui.autozmqtopicsCheckBox.setChecked(self.autozmqtopics)
         self.__ui.interruptCheckBox.setChecked(self.interruptonerror)
@@ -459,9 +497,12 @@ class ConfigDialog(QtGui.QDialog):
         self.__ui.storegeometryCheckBox.setChecked(self.storegeometry)
         self.__ui.fetchgeometryCheckBox.setChecked(self.geometryfromsource)
         self.__ui.sendroisCheckBox.setChecked(self.sendrois)
+        self.__ui.sendresultsCheckBox.setChecked(self.sendresults)
+        self.__ui.singleroisCheckBox.setChecked(self.singlerois)
         self.__ui.showallroisCheckBox.setChecked(self.showallrois)
         self.__ui.sourcedisplayCheckBox.setChecked(self.sourcedisplay)
         self.__ui.crosshairCheckBox.setChecked(self.crosshairlocker)
+        self.__ui.csaCheckBox.setChecked(self.correctsolidangle)
 
         if self.floattype not in ["float", "float32", "float64"]:
             self.floattype = "float"
@@ -717,11 +758,13 @@ class ConfigDialog(QtGui.QDialog):
         self.door = str(self.__ui.doorLineEdit.text()).strip()
         self.addrois = self.__ui.addroisCheckBox.isChecked()
         self.orderrois = self.__ui.orderroisCheckBox.isChecked()
+        self.imagechannels = self.__ui.imagechannelsCheckBox.isChecked()
         self.hidraport = str(self.__ui.hidraportLineEdit.text()).strip()
         self.maxmbuffersize = str(self.__ui.mbufsizeLineEdit.text()).strip()
         self.secstream = self.__ui.secstreamCheckBox.isChecked()
         self.zeromask = self.__ui.zeromaskCheckBox.isChecked()
         self.nanmask = self.__ui.nanmaskCheckBox.isChecked()
+        self.negmask = self.__ui.negmaskCheckBox.isChecked()
         self.secautoport = self.__ui.secautoportCheckBox.isChecked()
         self.refreshrate = float(self.__ui.rateDoubleSpinBox.value())
         self.floattype = str(self.__ui.floatComboBox.currentText())
@@ -731,7 +774,10 @@ class ConfigDialog(QtGui.QDialog):
             self.__ui.pollingintervalDoubleSpinBox.value())
         self.nrsources = int(
             self.__ui.nrsourcesSpinBox.value())
+        self.diffnpt = int(
+            self.__ui.diffsizeSpinBox.value())
         self.showsub = self.__ui.showsubCheckBox.isChecked()
+        self.showsubsf = self.__ui.showsubsfCheckBox.isChecked()
         self.showtrans = self.__ui.showtransCheckBox.isChecked()
         self.showmbuffer = self.__ui.showmbufferCheckBox.isChecked()
         self.showrange = self.__ui.showrangeCheckBox.isChecked()
@@ -749,6 +795,7 @@ class ConfigDialog(QtGui.QDialog):
         self.aspectlocked = self.__ui.aspectlockedCheckBox.isChecked()
         self.autodownsample = self.__ui.downsampleCheckBox.isChecked()
         self.keepcoords = self.__ui.keepCoordsCheckBox.isChecked()
+        self.accelbuffersum = self.__ui.buffersumCheckBox.isChecked()
         self.lazyimageslider = self.__ui.lazyimageCheckBox.isChecked()
         self.statswoscaling = not self.__ui.statsscaleCheckBox.isChecked()
         self.nxsopen = self.__ui.nxsopenCheckBox.isChecked()
@@ -756,10 +803,13 @@ class ConfigDialog(QtGui.QDialog):
         self.storegeometry = self.__ui.storegeometryCheckBox.isChecked()
         self.geometryfromsource = self.__ui.fetchgeometryCheckBox.isChecked()
         self.sendrois = self.__ui.sendroisCheckBox.isChecked()
+        self.sendresults = self.__ui.sendresultsCheckBox.isChecked()
+        self.singlerois = self.__ui.singleroisCheckBox.isChecked()
         self.showallrois = self.__ui.showallroisCheckBox.isChecked()
         self.sourcedisplay = self.__ui.sourcedisplayCheckBox.isChecked()
         self.defdetservers = self.__ui.defdetserversCheckBox.isChecked()
         self.crosshairlocker = self.__ui.crosshairCheckBox.isChecked()
+        self.correctsolidangle = self.__ui.csaCheckBox.isChecked()
 
         try:
             dirtrans = str(self.__ui.dirtransLineEdit.text()).strip()
@@ -886,10 +936,21 @@ class ConfigDialog(QtGui.QDialog):
             return
         zmqtopics = str(self.__ui.zmqtopicsLineEdit.text()).strip().split(" ")
         self.zmqtopics = [tp for tp in zmqtopics if tp]
+        self.interruptonerror = self.__ui.interruptCheckBox.isChecked()
+        self.autozmqtopics = self.__ui.autozmqtopicsCheckBox.isChecked()
+        datasources = str(
+            self.__ui.asapodatasourcesLineEdit.text()).strip().split(" ")
+        self.asapodatasources = [tp for tp in datasources if tp]
+        self.asaposerver = str(
+            self.__ui.asaposerverLineEdit.text()).strip()
+        self.asapotoken = str(
+            self.__ui.asapotokenLineEdit.text()).strip()
+        self.asapobeamtime = str(
+            self.__ui.asapobeamtimeLineEdit.text()).strip()
+        self.asaposourcepath = str(
+            self.__ui.asaposourcepathLineEdit.text()).strip()
         detservers = str(
             self.__ui.detserversLineEdit.text()).strip().split(" ")
-        self.autozmqtopics = self.__ui.autozmqtopicsCheckBox.isChecked()
-        self.interruptonerror = self.__ui.interruptCheckBox.isChecked()
         self.detservers = json.dumps([ds for ds in detservers if ds])
         try:
             self.timeout = int(self.__ui.timeoutLineEdit.text())
