@@ -38,7 +38,11 @@ from . import memoExportDialog
 
 _VMAJOR, _VMINOR, _VPATCH = _pg.__version__.split(".")[:3] \
     if _pg.__version__ else ("0", "9", "0")
-
+try:
+    _NPATCH = int(_VPATCH)
+except Exception:
+    _NPATCH = 0
+_PQGVER = int(_VMAJOR) * 1000 + int(_VMINOR) * 100 + _NPATCH
 
 logger = logging.getLogger("lavue")
 
@@ -198,10 +202,14 @@ class ImageDisplayWidget(_pg.GraphicsLayoutWidget):
         self.__autodownsample = True
         #: ([:obj:`float`, :obj:`float`]) minimum and maximum intensity levels
         self.__displaylevels = [None, None]
+        #: (:obj: `list` < [:obj:`float`, :obj:`float`] >) channel levels
+        self.__channellevels = None
         #: (:obj:`bool`) lock for double click
         self.__doubleclicklock = False
         #: (:obj:`bool`) rgb on flag
         self.__rgb = False
+        #: (:obj:`str`) levelmode
+        self.__levelmode = 'mono'
         #: (:obj:`dict` < :obj:`str`, :obj:`DisplayExtension` >)
         #          extension dictionary with name keys
         self.__extensions = {}
@@ -209,7 +217,7 @@ class ImageDisplayWidget(_pg.GraphicsLayoutWidget):
         self.__setaspectlocked = QtGui.QAction(
             "Set Aspect Locked", self.__viewbox.menu)
         self.__setaspectlocked.setCheckable(True)
-        if _VMAJOR == '0' and int(_VMINOR) < 10 and int(_VPATCH) < 9:
+        if _PQGVER < 1009:
             self.__viewbox.menu.axes.insert(0, self.__setaspectlocked)
         self.__viewbox.menu.addAction(self.__setaspectlocked)
 
@@ -217,7 +225,7 @@ class ImageDisplayWidget(_pg.GraphicsLayoutWidget):
         self.__viewonetoone = QtGui.QAction(
             "View 1:1 pixels", self.__viewbox.menu)
         self.__viewonetoone.triggered.connect(self._oneToOneRange)
-        if _VMAJOR == '0' and int(_VMINOR) < 10 and int(_VPATCH) < 9:
+        if _PQGVER < 1009:
             self.__viewbox.menu.axes.insert(0, self.__viewonetoone)
         self.__viewbox.menu.addAction(self.__viewonetoone)
 
@@ -395,12 +403,12 @@ class ImageDisplayWidget(_pg.GraphicsLayoutWidget):
         self.__image.resetTransform()
         if axes.scale is not None and anyupdate:
             if not self.__transformations.transpose:
-                self.__image.scale(*axes.scale)
+                self._imagescale(*axes.scale)
             else:
-                self.__image.scale(
+                self._imagescale(
                     axes.scale[1], axes.scale[0])
         else:
-            self.__image.scale(1, 1)
+            self._imagescale(1, 1)
         if axes.position is not None and anyupdate:
             if self.__transformations.orgtranspose and wrenabled:
                 self.__image.setPos(
@@ -415,6 +423,21 @@ class ImageDisplayWidget(_pg.GraphicsLayoutWidget):
         if self.sceneObj.rawdata is not None and update:
             self.autoRange()
 
+    def _imagescale(self, x, y):
+        """ set image scale x,y
+
+        :param x: x pixel coordinate
+        :type x: float
+        :param y: y pixel coordinate
+        :type y: float
+        """
+        try:
+            tr = self.__image.transform()
+            tr.scale(x, y)
+            self.__image.setTransform(tr)
+        except Exception:
+            self.__image.scale(x, y)
+
     def setToolScale(self, position=None, scale=None):
         """ set axes scales
 
@@ -474,7 +497,7 @@ class ImageDisplayWidget(_pg.GraphicsLayoutWidget):
         if axes.scale is not None or axes.position is not None:
             self.__image.resetTransform()
         if axes.scale is not None:
-            self.__image.scale(1, 1)
+            self._imagescale(1, 1)
         if axes.position is not None:
             self.__image.setPos(0, 0)
         if axes.scale is not None or axes.position is not None:
@@ -495,10 +518,23 @@ class ImageDisplayWidget(_pg.GraphicsLayoutWidget):
                 self.__image.setLookupTable(None)
                 if img.dtype.kind == 'f' and np.isnan(img.min()):
                     img = np.nan_to_num(img)
-                self.__image.setImage(
-                    img, lut=None,
-                    # levels=[[0,255], [0, 255], [0, 255]],
-                    autoLevels=False)
+                if self.__channellevels and self.levelMode() != 'mono':
+
+                    self.__image.setImage(
+                        img, lut=None,
+                        levels=self.__channellevels,
+                        autoLevels=False)
+                elif self.__displaylevels[0] is not None \
+                        and self.__displaylevels[1] is not None:
+                    self.__image.setImage(
+                        img, lut=None,
+                        levels=self.__displaylevels,
+                        autoLevels=False)
+                else:
+                    self.__image.setImage(
+                        img, lut=None,
+                        # levels=[[0,255], [0, 255], [0, 255]],
+                        autoLevels=False)
             elif (self.__autodisplaylevels
                   and self.__displaylevels[0] is not None
                   and self.__displaylevels[1] is not None):
@@ -816,6 +852,15 @@ class ImageDisplayWidget(_pg.GraphicsLayoutWidget):
         if level is not None:
             self.__displaylevels[1] = level
 
+    def setDisplayChannelLevels(self, levels=None):
+        """ sets maximum intensity levels
+
+        :param levels: channel intensity levels
+        :type levels: :obj:`list` < (:obj`float`:, :obj`float`:)>
+        """
+        if levels is not None:
+            self.__channellevels = levels
+
     def setDoubleClickLock(self, status=True):
         """ sets double click lock
         :param status: status flag
@@ -1092,8 +1137,13 @@ class ImageDisplayWidget(_pg.GraphicsLayoutWidget):
                 self.__viewbox, tuple(self.__viewbox.state['viewRange'][0]))
             self.__viewbox.sigYRangeChanged.emit(
                 self.__viewbox, tuple(self.__viewbox.state['viewRange'][1]))
-            self.__viewbox.sigRangeChanged.emit(
-                self.__viewbox, self.__viewbox.state['viewRange'])
+            if _PQGVER < 1202:
+                self.__viewbox.sigRangeChanged.emit(
+                    self.__viewbox, self.__viewbox.state['viewRange'])
+            else:
+                self.__viewbox.sigRangeChanged.emit(
+                    self.__viewbox, self.__viewbox.state['viewRange'],
+                    [True, True])
 
         if self.__transformations.updownflip != updownflip:
             self.__transformations.updownflip = updownflip
@@ -1103,8 +1153,13 @@ class ImageDisplayWidget(_pg.GraphicsLayoutWidget):
                 self.__viewbox, tuple(self.__viewbox.state['viewRange'][0]))
             self.__viewbox.sigYRangeChanged.emit(
                 self.__viewbox, tuple(self.__viewbox.state['viewRange'][1]))
-            self.__viewbox.sigRangeChanged.emit(
-                self.__viewbox, self.__viewbox.state['viewRange'])
+            if _PQGVER < 1202:
+                self.__viewbox.sigRangeChanged.emit(
+                    self.__viewbox, self.__viewbox.state['viewRange'])
+            else:
+                self.__viewbox.sigRangeChanged.emit(
+                    self.__viewbox, self.__viewbox.state['viewRange'],
+                    [True, True])
 
     def transformations(self):
         """ povides coordinates transformations
@@ -1184,3 +1239,19 @@ class ImageDisplayWidget(_pg.GraphicsLayoutWidget):
         :rtype: :obj:`bool`
         """
         return self.__rgb
+
+    def setLevelMode(self, levelmode=True):
+        """ sets levelmode
+
+        :param levelmode: level mode, i.e. `mono` or `rgba`
+        :type levelmode: :obj:`str`
+        """
+        self.__levelmode = levelmode
+
+    def levelMode(self):
+        """ gets level mode
+
+        :returns: level mode, i.e. `mono` or `rgba`
+        :rtype: :obj:`str`
+        """
+        return self.__levelmode
