@@ -37,6 +37,16 @@ import math
 import os
 import logging
 
+
+_VMAJOR, _VMINOR, _VPATCH = _pg.__version__.split(".")[:3] \
+    if _pg.__version__ else ("0", "9", "0")
+try:
+    _NPATCH = int(_VPATCH)
+except Exception:
+    _NPATCH = 0
+_PQGVER = int(_VMAJOR) * 1000 + int(_VMINOR) * 100 + _NPATCH
+
+
 _formclass, _baseclass = uic.loadUiType(
     os.path.join(os.path.dirname(os.path.abspath(__file__)),
                  "ui", "LevelsGroupBox.ui"))
@@ -55,6 +65,8 @@ class LevelsGroupBox(QtGui.QWidget):
     minLevelChanged = QtCore.pyqtSignal(float)
     #: (:class:`pyqtgraph.QtCore.pyqtSignal`) maximum level changed signal
     maxLevelChanged = QtCore.pyqtSignal(float)
+    #: (:class:`pyqtgraph.QtCore.pyqtSignal`) channel levels changed signal
+    channelLevelsChanged = QtCore.pyqtSignal()
     #: (:class:`pyqtgraph.QtCore.pyqtSignal`) automatic levels changed signal
     autoLevelsChanged = QtCore.pyqtSignal(int)
     #: (:class:`pyqtgraph.QtCore.pyqtSignal`) levels changed signal
@@ -87,7 +99,7 @@ class LevelsGroupBox(QtGui.QWidget):
         #: (:obj: `bool`) levels shown
         self.__levels = True
         #: (:obj: `str`) scale label
-        self.__scaling = ""
+        self.__scaling = "sqrt"
         #: (:class:`lavuelib.settings.Settings`) settings
         self.__settings = settings
         #: (:obj:`bool`) expert mode
@@ -101,9 +113,14 @@ class LevelsGroupBox(QtGui.QWidget):
             self._addGradientItem(name)
 
         #: (:obj: `float`) minimum intensity level value
-        self.__minval = 0.1
+        self.__minval = 0.2
         #: (:obj: `float`) maximum intensity level value
-        self.__maxval = 1.
+        self.__maxval = 1.1
+        #: (:obj: `float`) minimum maximum intensity level value
+        #                  for separete channels
+        self.__channels = None
+        #: (:obj: `int`) channel to display
+        self.__dchl = 0
 
         self.__ui.minDoubleSpinBox.setMinimum(-10e20)
         self.__ui.minDoubleSpinBox.setMaximum(10e20)
@@ -131,19 +148,135 @@ class LevelsGroupBox(QtGui.QWidget):
             self._onAutoLevelsChanged)
         self.__ui.stepLineEdit.textChanged.connect(
             self._onStepChanged)
+        self.__ui.monoRadioButton.clicked.connect(
+            self._monoLevelMode)
+        self.__ui.redRadioButton.clicked.connect(
+            self._redLevelMode)
+        self.__ui.blueRadioButton.clicked.connect(
+            self._blueLevelMode)
+        self.__ui.greenRadioButton.clicked.connect(
+            self._greenLevelMode)
         self.__ui.autofactorLineEdit.textChanged.connect(
             self._onAutoFactorChanged)
         self.__connectHistogram()
-        self.updateLevels(self.__minval, self.__maxval)
+        self.updateLevels(0.1, 1.0)
         self.__connectMinMax()
+        self.__levelmode = "mono"
+
+    def _updateLevelLabels(self, dchl=None):
+        """ update level labels
+
+        :param dchl: channel id
+        :type dchl: :obj:`int`
+        """
+        if dchl is None:
+            dchl = self.__dchl
+        if _PQGVER >= 1100:
+            if dchl == 1:
+                self.__ui.minLabel.setText("Red Min. value:")
+                self.__ui.maxLabel.setText("Red Max. value:")
+            elif dchl == 2:
+                self.__ui.minLabel.setText("Green Min. value:")
+                self.__ui.maxLabel.setText("Green Max. value:")
+            elif dchl == 3:
+                self.__ui.minLabel.setText("Blue Min. value:")
+                self.__ui.maxLabel.setText("Blue Max. value:")
+            else:
+                self.__ui.minLabel.setText("Minimum value:")
+                self.__ui.maxLabel.setText("Maximum value:")
+
+    @QtCore.pyqtSlot(bool)
+    def _monoLevelMode(self, status):
+        """ update to the mono level mode
+
+        :param status: button status
+        :type status: :obj:`bool`
+        """
+        if _PQGVER >= 1100:
+            if status:
+                self.__dchl = 0
+                self._updateLevelLabels()
+                if not self.__histo:
+                    self.__histogram.switchLevelMode('mono')
+                self.__levelmode = "mono"
+                self.updateLevels(self.__minval, self.__maxval)
+                if self.__histogram:
+                    self.__histogram.switchLevelMode('mono')
+
+    @QtCore.pyqtSlot(bool)
+    def _redLevelMode(self, status):
+        """ update to the red level mode
+
+        :param status: button status
+        :type status: :obj:`bool`
+        """
+        if _PQGVER >= 1100:
+            if status:
+                self.__dchl = 1
+                self._updateLevelLabels()
+                if not self.__histo:
+                    self.__histogram.switchLevelMode('rgba')
+                self.__levelmode = "rgba"
+                if self.__channels is not None:
+                    while len(self.__channels) < 1:
+                        self.__channels.append((self.__minval, self.__maxval))
+                    self.updateLevels(None, None, self.__channels)
+                if self.__histogram:
+                    self.__histogram.switchLevelMode('rgba')
+
+    @QtCore.pyqtSlot(bool)
+    def _greenLevelMode(self, status):
+        """ update to the green level mode
+
+        :param status: button status
+        :type status: :obj:`bool`
+        """
+        if _PQGVER >= 1100:
+            if status:
+                self.__dchl = 2
+                self._updateLevelLabels()
+                if not self.__histo:
+                    self.__histogram.switchLevelMode('rgba')
+                self.__levelmode = "rgba"
+                if self.__channels is not None:
+                    while len(self.__channels) < 2:
+                        self.__channels.append((self.__minval, self.__maxval))
+                    self.updateLevels(None, None, self.__channels)
+                if self.__histogram:
+                    self.__histogram.switchLevelMode('rgba')
+
+    @QtCore.pyqtSlot(bool)
+    def _blueLevelMode(self, status):
+        """ update to the blue level mode
+
+        :param status: button status
+        :type status: :obj:`bool`
+        """
+        if _PQGVER >= 1100:
+            if status:
+                self.__dchl = 3
+                self._updateLevelLabels()
+                if not self.__histo:
+                    self.__histogram.switchLevelMode('rgba')
+                self.__levelmode = "rgba"
+                if self.__channels is not None:
+                    while len(self.__channels) < 3:
+                        self.__channels.append((self.__minval, self.__maxval))
+                    self.updateLevels(None, None, self.__channels)
+                if self.__histogram:
+                    self.__histogram.switchLevelMode('rgba')
 
     def __connectHistogram(self):
         """ create histogram object and connect its signals
         """
-        self.__histogram.item.sigLevelsChanged.connect(self._onLevelsChanged)
-        self.__histogram.sigNameChanged.connect(self._changeGradient)
-        self.__histogram.saveGradientRequested.connect(self._saveGradient)
-        self.__histogram.removeGradientRequested.connect(self._removeGradient)
+        self.__histogram.item.sigLevelsChanged.connect(
+            self._onLevelsChanged)
+        self.__histogram.sigNameChanged.connect(
+            self._changeGradient)
+        self.__histogram.saveGradientRequested.connect(
+            self._saveGradient)
+        self.__histogram.removeGradientRequested.connect(
+            self._removeGradient)
 
     def __disconnectHistogram(self):
         """ remove histogram object and disconnect its signals
@@ -186,18 +319,34 @@ class LevelsGroupBox(QtGui.QWidget):
         if not self.__auto:
             try:
                 self.__disconnectMinMax()
+                if self.__histo:
+                    self.__disconnectHistogram()
                 self._checkAndEmit()
                 if self.__histo:
                     lowlim = self.__ui.minDoubleSpinBox.value()
                     uplim = self.__ui.maxDoubleSpinBox.value()
-                    self.__histogram.region.setRegion([lowlim, uplim])
+                    if self.__dchl == 0:
+                        self.__histogram.region.setRegion([lowlim, uplim])
+                    else:
+                        self.__histogram.regions[self.__dchl].setRegion(
+                            [lowlim, uplim])
             finally:
                 self.__connectMinMax()
+                if self.__histo:
+                    self.__connectHistogram()
         else:
             lowlim = self.__ui.minDoubleSpinBox.value()
             uplim = self.__ui.maxDoubleSpinBox.value()
-            self.minLevelChanged.emit(lowlim)
-            self.maxLevelChanged.emit(uplim)
+            if self.__dchl == 0:
+                self.minLevelChanged.emit(lowlim)
+                self.maxLevelChanged.emit(uplim)
+            else:
+                if self.__channels is None:
+                    self.__channels = []
+                    while len(self.__channels) < self.__dchl:
+                        self.__channels.append((lowlim, uplim))
+                    self.__channels[self.__dchl - 1] = (lowlim, uplim)
+                self.channelLevelsChanged.emit()
 
     def changeView(self, showhistogram=None, showlevels=None,
                    showadd=None):
@@ -356,63 +505,186 @@ class LevelsGroupBox(QtGui.QWidget):
         self.levelsChanged.emit()
 
     @QtCore.pyqtSlot(object)
-    def _onLevelsChanged(self, histogram):
+    def _onLevelsChanged(self, histogram=None):
         """ set min/max level spinboxes according to histogram
 
         :param histogram: intensity histogram object
         :type histogram: :class: `lavuelib.histogramWidget.HistogramHLUTWidget`
 
         """
+        if histogram is None:
+            histogram = self.__histogram
         levels = histogram.region.getRegion()
+        lowlim = self.__minval
+        uplim = self.__maxval
+        changed = False
+        try:
+            # self.__disconnectMinMax()
+            # self.__disconnectHistogram()
+
+            if levels[0] != lowlim or levels[1] != uplim:
+                lowlim = levels[0]
+                uplim = levels[1]
+                # refresh widget
+                changed = True
+                self.__minval = levels[0]
+                self.__maxval = levels[1]
+                if self.__dchl == 0:
+                    self.__ui.minDoubleSpinBox.setValue(levels[0])
+                    self.__ui.maxDoubleSpinBox.setValue(levels[1])
+            # #TODO channels
+            if hasattr(self.__histogram, "regions") and \
+               self.__channels is not None:
+                while len(self.__channels) < 3:
+                    self.__channels.append((self.__minval, self.__maxval))
+                    added = True
+                for i in range(1, 4):
+                    levels = histogram.regions[i].getRegion()
+                    lowlim = self.__channels[i - 1][0]
+                    uplim = self.__channels[i - 1][1]
+                    added = False
+                    if levels[0] != lowlim or levels[1] != uplim or added:
+                        lowlim = levels[0]
+                        uplim = levels[1]
+                        # refresh widget
+                        changed = True
+                        self.__channels[i - 1] = levels[0], levels[1]
+                if self.__dchl > 0:
+                    self.__ui.minDoubleSpinBox.setValue(
+                        self.__channels[self.__dchl - 1][0])
+                    self.__ui.maxDoubleSpinBox.setValue(
+                        self.__channels[self.__dchl - 1][1])
+        finally:
+            # self.__connectMinMax()
+            # self.__connectHistogram()
+            pass
+        if not self.__auto and changed:
+            self._checkLevels()
+            self._emitLevels()
+
+    @QtCore.pyqtSlot()
+    def _checkLevels(self):
+        """ checks if the minimum value is actually smaller than the maximum
+        """
+        minval = self.__ui.minDoubleSpinBox.value()
+        maxval = self.__ui.maxDoubleSpinBox.value()
+        if maxval >= 10e+20:
+            maxval = self.__maxval
+        if minval >= 10e+20:
+            minval = self.__minval
+
+        if maxval - minval <= 0:
+            if minval >= 1.:
+                minval = maxval - 1.
+            else:
+                maxval = minval + 1
+
+        self.__ui.minDoubleSpinBox.setValue(minval)
+        self.__ui.maxDoubleSpinBox.setValue(maxval)
+
+    @QtCore.pyqtSlot()
+    def _emitLevels(self):
+        """ checks if the minimum value is actually smaller than the maximum
+        """
+        self.minLevelChanged.emit(self.__minval)
+        self.maxLevelChanged.emit(self.__maxval)
+        self.channelLevelsChanged.emit()
+
+    @QtCore.pyqtSlot()
+    def _updateAndEmit(self):
         lowlim = self.__ui.minDoubleSpinBox.value()
         uplim = self.__ui.maxDoubleSpinBox.value()
-        if levels[0] != lowlim or levels[1] != uplim:
-            self.__ui.minDoubleSpinBox.setValue(levels[0])
-            self.__ui.maxDoubleSpinBox.setValue(levels[1])
-            if not self.__auto:
-                self._checkAndEmit()
+        if self.__dchl == 0:
+            self.__minval = lowlim
+            self.__maxval = uplim
+            self.minLevelChanged.emit(self.__minval)
+            self.maxLevelChanged.emit(self.__maxval)
+        else:
+            if self.__channels is None:
+                self.__channels = []
+            while len(self.__channels) < self.__dchl:
+                self.__channels.append((lowlim, uplim))
+            self.__channels[self.__dchl - 1] = (lowlim, uplim)
+            self.channelLevelsChanged.emit()
 
     @QtCore.pyqtSlot()
     def _checkAndEmit(self):
         """ checks if the minimum value is actually smaller than the maximum
         """
-        self.__minval = self.__ui.minDoubleSpinBox.value()
-        self.__maxval = self.__ui.maxDoubleSpinBox.value()
-        if self.__maxval - self.__minval <= 0:
-            if self.__minval >= 1.:
-                self.__minval = self.__maxval - 1.
+        self._checkLevels()
+        self._updateAndEmit()
+
+    def updateLevels(self, lowlim, uplim, channels=None, signals=True,
+                     force=False):
+        """ set min/max level spinboxes and histogram from the parameters
+
+        :param lowlim: minimum intensity value
+        :type lowlim: :obj:`float`
+        :param uplim:  maximum intensity value
+        :type uplim: :obj:`float`
+        :param signal:  dont disconnect signals
+        :type signal: :obj:`bool`
+        :param force:  force update histogram
+        :type force: :obj:`bool`
+        """
+        try:
+            if not signals:
+                self.__disconnectMinMax()
+
+            if lowlim is not None:
+                self.__minval = lowlim
+                if self.__dchl == 0:
+                    self.__ui.minDoubleSpinBox.setValue(lowlim)
             else:
-                self.__maxval = self.__minval + 1
+                lowlim = self.__minval
+            if uplim is not None:
+                self.__maxval = uplim
+                if self.__dchl == 0:
+                    self.__ui.maxDoubleSpinBox.setValue(uplim)
+            else:
+                uplim = self.__maxval
+            if channels is not None:
+                self.__channels = channels
+                if self.__dchl != 0 and len(self.__channels) >= self.__dchl:
+                    ch = self.__channels[self.__dchl - 1]
+                    if ch is not None:
+                        chl, chh = ch
+                        self.__ui.minDoubleSpinBox.setValue(chl)
+                        self.__ui.maxDoubleSpinBox.setValue(chh)
+        finally:
+            if not signals:
+                self.__connectMinMax()
 
-        self.__ui.minDoubleSpinBox.setValue(self.__minval)
-        self.__ui.maxDoubleSpinBox.setValue(self.__maxval)
-
-        self.minLevelChanged.emit(self.__minval)
-        self.maxLevelChanged.emit(self.__maxval)
-        self.levelsChanged.emit()
-
-    def updateLevels(self, lowlim, uplim):
-        """ set min/max level spinboxes and histogram from the parameters
-
-        :param lowlim: minimum intensity value
-        :type lowlim: :obj:`float`
-        :param uplim:  maximum intensity value
-        :type uplim: :obj:`float`
-        """
-        if lowlim is not None:
-            self.__ui.minDoubleSpinBox.setValue(lowlim)
-        else:
-            lowlim = self.__ui.minDoubleSpinBox.value()
-        if uplim is not None:
-            self.__ui.maxDoubleSpinBox.setValue(uplim)
-        else:
-            uplim = self.__ui.maxDoubleSpinBox.value()
-        if self.__histo and self.__auto:
+        if self.__histo and (self.__auto or force):
             levels = self.__histogram.region.getRegion()
-            if levels[0] != lowlim or levels[1] != uplim:
-                self.__histogram.region.setRegion([lowlim, uplim])
+            update = False
+            try:
+                if self.__histo:
+                    self.__disconnectHistogram()
 
-    def updateAutoLevels(self, lowlim, uplim):
+                if levels[0] != lowlim or levels[1] != uplim or force:
+                    if self.__histo:
+                        self.__histogram.region.setRegion([lowlim, uplim])
+                if hasattr(self.__histogram, "regions"):
+                    if channels is not None and self.__histo:
+                        for i, ch in enumerate(self.__channels):
+                            if ch is not None:
+                                lowlim, uplim = ch
+                                if lowlim is not None and uplim is not None:
+                                    levels = self.__histogram.regions[i + 1]\
+                                                             .getRegion()
+                                    if levels[0] != lowlim \
+                                       or levels[1] != uplim or force:
+                                        self.__histogram.regions[i + 1].\
+                                            setRegion([lowlim, uplim])
+            finally:
+                if self.__histo:
+                    self.__connectHistogram()
+            if update:
+                self._onLevelsChanged()
+        self._emitLevels()
+
+    def updateAutoLevels(self, lowlim, uplim, channels=None):
         """ set min/max level spinboxes and histogram from the parameters
 
         :param lowlim: minimum intensity value
@@ -420,18 +692,29 @@ class LevelsGroupBox(QtGui.QWidget):
         :param uplim:  maximum intensity value
         :type uplim: :obj:`float`
         """
+        if channels is not None:
+            self.__channels = channels
         try:
             factor = str(self.__ui.autofactorLineEdit.text())
             float(factor)
-            llim, ulim = self.__histogram.getFactorRegion()
+            channels = None
+            llim = None
+            ulim = None
+            if self.__histo:
+                llim, ulim = self.__histogram.getFactorRegion()
+                channels = self.__histogram.getChannelFactorRegion()
+            if channels is not None:
+                self.__channels = channels
             if llim is not None and ulim is not None:
                 self.updateLevels(llim, ulim)
                 self.minLevelChanged.emit(llim)
                 self.maxLevelChanged.emit(ulim)
             else:
-                self.updateLevels(lowlim, uplim)
+                self.updateLevels(lowlim, uplim, channels)
+                if channels is not None:
+                    self.channelLevelsChanged.emit()
         except Exception:
-            self.updateLevels(lowlim, uplim)
+            self.updateLevels(lowlim, uplim, channels)
 
     def __hideControls(self):
         """ disables spinboxes
@@ -449,6 +732,67 @@ class LevelsGroupBox(QtGui.QWidget):
         self.__ui.autofactorLineEdit.setEnabled(False)
         self.__ui.autofactorLabel.setEnabled(False)
 
+    def _tologscale(self, lowlim, uplim):
+        """ change scaling to log scale
+
+        :param lowlim: minimum intensity value
+        :type lowlim: :obj:`float`
+        :param uplim:  maximum intensity value
+        :type uplim: :obj:`float`
+        :returns: (minimum intensity value, maximum intensity value)
+                  in log scale
+        :rtype: (:obj:`float`, :obj:`float`)
+        """
+        if self.__scaling == "linear":
+            lowlim = math.log10(
+                lowlim or 10e-3) if lowlim > 0 else -2
+            uplim = math.log10(
+                uplim or 10e-3) if uplim > 0 else -2
+        elif self.__scaling == "sqrt":
+            lowlim = math.log10(
+                lowlim * lowlim or 10e-3) if lowlim > 0 else -2
+            uplim = math.log10(
+                uplim * uplim or 10e-3) if uplim > 0 else -2
+        return lowlim, uplim
+
+    def _tolinearscale(self, lowlim, uplim):
+        """ change scaling to linear scale
+
+        :param lowlim: minimum intensity value
+        :type lowlim: :obj:`float`
+        :param uplim:  maximum intensity value
+        :type uplim: :obj:`float`
+        :returns: (minimum intensity value, maximum intensity value)
+                  in linear scale
+        :rtype: (:obj:`float`, :obj:`float`)
+        """
+        if self.__scaling == "log":
+            lowlim = math.pow(10, lowlim)
+            uplim = math.pow(10, uplim)
+        elif self.__scaling == "sqrt":
+            lowlim = lowlim * lowlim
+            uplim = uplim * uplim
+        return lowlim, uplim
+
+    def _tosqrtscale(self, lowlim, uplim):
+        """ change scaling to sqrt scale
+
+        :param lowlim: minimum intensity value
+        :type lowlim: :obj:`float`
+        :param uplim:  maximum intensity value
+        :type uplim: :obj:`float`
+        :returns: (minimum intensity value, maximum intensity value)
+                  in sqrt scale
+        :rtype: (:obj:`float`, :obj:`float`)
+        """
+        if self.__scaling == "linear":
+            lowlim = math.sqrt(max(lowlim, 0))
+            uplim = math.sqrt(max(uplim, 0))
+        elif self.__scaling == "log":
+            lowlim = math.sqrt(max(math.pow(10, lowlim), 0))
+            uplim = math.sqrt(max(math.pow(10, uplim), 0))
+        return lowlim, uplim
+
     @QtCore.pyqtSlot(str)
     def setScalingLabel(self, scalingtype):
         """ sets scaling label
@@ -456,47 +800,61 @@ class LevelsGroupBox(QtGui.QWidget):
         :param scalingtype: scaling type, i.e. log, linear, sqrt
         :type scalingtype: :obj:`str`
         """
+        # TODO channels
+
         lowlim = float(self.__ui.minDoubleSpinBox.value())
         uplim = float(self.__ui.maxDoubleSpinBox.value())
-        if scalingtype == "log":
+        scalefun = {
+            "log": self._tologscale,
+            "linear": self._tolinearscale,
+            "sqrt": self._tosqrtscale,
+        }
+        scalelabel = {
+            "log": "log scale!",
+            "linear": "log linear!",
+            "sqrt": "log sqrt!",
+        }
+        if scalingtype in scalefun.keys():
+            sfun = scalefun[scalingtype]
+            slabel = scalelabel[scalingtype]
             if scalingtype != self.__scaling:
-                self.__ui.scalingLabel.setText("log scale!")
+                self.__ui.scalingLabel.setText(slabel)
                 if not self.__auto:
-                    if self.__scaling == "linear":
-                        lowlim = math.log10(
-                            lowlim or 10e-3) if lowlim > 0 else -2
-                        uplim = math.log10(
-                            uplim or 10e-3) if uplim > 0 else -2
-                    elif self.__scaling == "sqrt":
-                        lowlim = math.log10(
-                            lowlim * lowlim or 10e-3) if lowlim > 0 else -2
-                        uplim = math.log10(
-                            uplim * uplim or 10e-3) if uplim > 0 else -2
-        elif scalingtype == "linear":
-            if scalingtype != self.__scaling:
-                self.__ui.scalingLabel.setText("linear scale!")
-                if not self.__auto:
-                    if self.__scaling == "log":
-                        lowlim = math.pow(10, lowlim)
-                        uplim = math.pow(10, uplim)
-                    elif self.__scaling == "sqrt":
-                        lowlim = lowlim * lowlim
-                        uplim = uplim * uplim
-        elif scalingtype == "sqrt":
-            if scalingtype != self.__scaling:
-                self.__ui.scalingLabel.setText("sqrt scale!")
-                if not self.__auto:
-                    if self.__scaling == "linear":
-                        lowlim = math.sqrt(max(lowlim, 0))
-                        uplim = math.sqrt(max(uplim, 0))
-                    elif self.__scaling == "log":
-                        lowlim = math.sqrt(max(math.pow(10, lowlim), 0))
-                        uplim = math.sqrt(max(math.pow(10, uplim), 0))
+                    lowlim, uplim = sfun(lowlim, uplim)
+                    self.__minval, self.__maxval = sfun(
+                        self.__minval, self.__maxval)
+                    if self.__channels:
+                        for i, ch in enumerate(self.__channels):
+                            if ch is not None:
+                                if ch[0] is not None and ch[1] is not None:
+                                    self.__channels[i] = sfun(ch[0], ch[1])
+
+            # self.__ui.minDoubleSpinBox.setValue(lowlim)
+            # self.__ui.maxDoubleSpinBox.setValue(uplim)
         if scalingtype != self.__scaling:
             self.__scaling = scalingtype
         if not self.__auto:
             if self.__histo:
-                self.__histogram.region.setRegion([lowlim, uplim])
+                try:
+                    self.__disconnectHistogram()
+                    self.__histogram.region.setRegion(
+                        [self.__minval, self.__maxval])
+                    if hasattr(self.__histogram, "regions"):
+                        if self.__channels is not None:
+                            for i, ch in enumerate(self.__channels):
+                                if ch is not None:
+                                    lowlim, uplim = ch
+                                    if lowlim is not None \
+                                       and uplim is not None:
+                                        self.__histogram.regions[i + 1].\
+                                            setRegion([lowlim, uplim])
+                finally:
+                    self.__connectHistogram()
+
+                    self.updateLevels(
+                        self.__minval, self.__maxval, self.__channels,
+                        signals=False)
+                    # self._onLevelsChanged()
             else:
                 self.__ui.minDoubleSpinBox.setValue(lowlim)
                 self.__ui.maxDoubleSpinBox.setValue(uplim)
@@ -509,10 +867,20 @@ class LevelsGroupBox(QtGui.QWidget):
         :type status: :obj:`bool`
         """
         self.__histogram.setRGB(status)
+        if status and self.__dchl:
+            mode = 'rgba'
+            dchl = self.__dchl
+        else:
+            mode = 'mono'
+            dchl = 0
+        self.__histogram.switchLevelMode(mode)
+        self._updateLevelLabels(dchl)
         self.showGradient(not status)
+        if _PQGVER >= 1100:
+            self.showChannels(status)
 
     def showGradient(self, status=True):
-        """ resets color channel
+        """ show/hide gradient widget
 
         :param status: show gradient flag
         :type status: :obj:`bool`
@@ -527,6 +895,18 @@ class LevelsGroupBox(QtGui.QWidget):
             self.__ui.gradientLabel.hide()
             self.__histogram.gradient.hide()
 
+    def showChannels(self, status=True):
+        """ show/hide channel widget
+
+        :param status: show channel flag
+        :type status: :obj:`bool`
+        """
+        if status:
+            self.__ui.channelWidget.show()
+        else:
+            self.__ui.channelWidget.hide()
+            # self.__ui.monoRadioButton.setChecked(2)
+
     @QtCore.pyqtSlot(int)
     def setBins(self, index):
         """ sets bins edges algorithm for histogram
@@ -681,39 +1061,105 @@ class LevelsGroupBox(QtGui.QWidget):
     def levels(self):
         """ provides levels from configuration string
 
-        :returns:  configuration string: lowlim,uplim
+        :returns:  configuration string: lowlim,uplim or
+                   lowlim,uplim;c1l,c1u;c2l,c2u;c3l,c3u
         :rtype: :obj:`str`
         """
-        lowlim = self.__ui.minDoubleSpinBox.value()
-        uplim = self.__ui.maxDoubleSpinBox.value()
-        return "%s,%s" % (lowlim, uplim)
+        lowlim = self.__minval
+        uplim = self.__maxval
+
+        main = "%s,%s" % (lowlim, uplim)
+        chl = ""
+        chw = ""
+        if self.__channels:
+            chl = ";".join(
+                ["%s,%s" % (ch[0], ch[1]) for ch in self.__channels])
+            chl = ";%s" % chl
+        if self.__dchl in [1, 2, 3]:
+            chw = ";%s" % ({1: "red", 2: "green", 3: "blue"}[self.__dchl])
+        return "%s%s%s" % (main, chl, chw)
+
+    def channelLevels(self):
+        """ provides levels from configuration string
+
+        :returns:  channel levels
+        :rtype: :obj:`str`
+        """
+        if self.__channels is not None:
+            return list(self.__channels)
 
     def setLevels(self, cnflevels):
         """ set levels from configuration string
 
-        :param cnflevels:  configuration string: lowlim,uplim
+        :param cnflevels:  configuration string: lowlim,uplim   or
+               lowlim,uplim;lowred,upred;lowgreen,upgreen;lowblue,upblue
         :type cnflevels: :obj:`str`
         """
-        self.__ui.autoLevelsCheckBox.setChecked(False)
-        self._onAutoLevelsChanged(0)
-        llst = cnflevels.split(",")
-        lmin = None
-        lmax = None
-        try:
-            smin = llst[0]
-            if smin.startswith("m"):
-                smin = "-" + smin[1:]
-            lmin = float(smin)
-        except Exception:
-            pass
-        try:
-            smax = llst[1]
-            if smax.startswith("m"):
-                smax = "-" + smax[1:]
-            lmax = float(smax)
-        except Exception:
-            pass
-        self.updateLevels(lmin, lmax)
+        dchl = 0
+        channels = None
+        if cnflevels:
+            clst = cnflevels.split(";")
+            if clst[-1].startswith("r") or clst[-1].startswith("R"):
+                dchl = 1
+                clst.pop()
+            elif clst[-1].startswith("g") or clst[-1].startswith("G"):
+                dchl = 2
+                clst.pop()
+            elif clst[-1].startswith("b") or clst[-1].startswith("B"):
+                dchl = 3
+                clst.pop()
+            channels = []
+            if clst:
+                self.__ui.autoLevelsCheckBox.setChecked(False)
+                self._onAutoLevelsChanged(0)
+                for ch in clst[1:]:
+                    llst = ch.split(",")
+                    lmin = None
+                    lmax = None
+                    try:
+                        smin = llst[0]
+                        if smin.startswith("m"):
+                            smin = "-" + smin[1:]
+                        lmin = float(smin)
+                    except Exception as e:
+                        logger.warning(str(e))
+                        # print(str(e))
+                    try:
+                        smax = llst[1]
+                        if smax.startswith("m"):
+                            smax = "-" + smax[1:]
+                        lmax = float(smax)
+                    except Exception as e:
+                        logger.warning(str(e))
+                    channels.append((lmin, lmax))
+
+                llst = clst[0].split(",")
+                lmin = None
+                lmax = None
+                try:
+                    smin = llst[0]
+                    if smin.startswith("m"):
+                        smin = "-" + smin[1:]
+                    lmin = float(smin)
+                except Exception:
+                    pass
+                try:
+                    smax = llst[1]
+                    if smax.startswith("m"):
+                        smax = "-" + smax[1:]
+                    lmax = float(smax)
+                except Exception:
+                    pass
+
+                self.updateLevels(lmin, lmax, channels, force=True)
+        if dchl == 0 and not self.__ui.monoRadioButton.isChecked():
+            self.__ui.monoRadioButton.click()
+        elif dchl == 1 and not self.__ui.redRadioButton.isChecked():
+            self.__ui.redRadioButton.click()
+        elif dchl == 2 and not self.__ui.greenRadioButton.isChecked():
+            self.__ui.greenRadioButton.click()
+        elif dchl == 3 and not self.__ui.blueRadioButton.isChecked():
+            self.__ui.blueRadioButton.click()
 
     def autoFactor(self):
         """ provides factor for automatic levels
@@ -733,3 +1179,13 @@ class LevelsGroupBox(QtGui.QWidget):
         if factor:
             self.setAutoLevels(2)
         self._onAutoFactorChanged(factor)
+
+    def levelMode(self):
+        """ return historgram level mode
+
+        :return: level mode
+        :rtype: :obj:`str`
+        """
+        if self.__histogram and self.__histo:
+            return self.__histogram.levelMode
+        return self.__levelmode
