@@ -29,11 +29,15 @@ from __future__ import print_function
 from __future__ import unicode_literals
 
 import time
-import logging
 import json
+import logging
 
 from pyqtgraph import QtCore
 
+from .omniQThread import OmniQThread
+# from .sardanaUtils import debugmethod
+
+
 #: (:obj:`float`) refresh rate in seconds
 GLOBALREFRESHRATE = .1
 #: (:obj:`float`) polling inverval in seconds
@@ -43,7 +47,7 @@ logger = logging.getLogger("lavue")
 
 
 # subclass for threading
-class MotorWatchThread(QtCore.QThread):
+class MotorWatchThread(OmniQThread):
 
     #: (:class:`pyqtgraph.QtCore.pyqtSignal`) signal with motor status
     motorStatusSignal = QtCore.pyqtSignal(float, str, float, str)
@@ -54,23 +58,24 @@ class MotorWatchThread(QtCore.QThread):
         """ constructor
 
         :param motor1: first motor device proxy
-        :type motor1: :class:`PyTango.DeviceProxy`
+        :type motor1: :class:`tango.DeviceProxy`
         :param motor2: second motor device proxy
-        :type motor2: :class:`PyTango.DeviceProxy`
+        :type motor2: :class:`tango.DeviceProxy`
         :param mserver: door server device proxy
-        :type mserver: :class:`PyTango.DeviceProxy`
+        :type mserver: :class:`tango.DeviceProxy`
         """
-        QtCore.QThread.__init__(self)
+        OmniQThread.__init__(self)
         #: (:obj:`bool`) execute loop flag
         self.__loop = False
-        #: (:class:`PyTango.DeviceProxy`) first motor device proxy
+        #: (:class:`tango.DeviceProxy`) first motor device proxy
         self.__motor1 = motor1
-        #: (:class:`PyTango.DeviceProxy`) second motor device proxy
+        #: (:class:`tango.DeviceProxy`) second motor device proxy
         self.__motor2 = motor2
-        #: (:class:`PyTango.DeviceProxy`) door server device proxy
+        #: (:class:`tango.DeviceProxy`) door server device proxy
         self.__mserver = server
 
-    def run(self):
+    # @debugmethod
+    def _run(self):
         """ runner of the fetching thread
         """
         self.__loop = True
@@ -97,7 +102,8 @@ class MotorWatchThread(QtCore.QThread):
             except Exception as e:
                 logger.warning(str(e))
 
-    def isRunning(self):
+    # @debugmethod
+    def isWatching(self):
         """ is datasource source connected
 
         :returns: if datasource source connected
@@ -105,6 +111,7 @@ class MotorWatchThread(QtCore.QThread):
         """
         return self.__loop
 
+    # @debugmethod
     def stop(self):
         """ stops loop
 
@@ -113,7 +120,7 @@ class MotorWatchThread(QtCore.QThread):
 
 
 # subclass for threading
-class AttributeWatchThread(QtCore.QThread):
+class AttributeWatchThread(OmniQThread):
 
     #: (:class:`pyqtgraph.QtCore.pyqtSignal`) signal with attribute values
     attrValuesSignal = QtCore.pyqtSignal(str)
@@ -124,24 +131,26 @@ class AttributeWatchThread(QtCore.QThread):
         """ constructor
 
         :param refreshtime: refresh time
-        :type refreshtime: :class:`PyTango.DeviceProxy`
+        :type refreshtime: :class:`tango.DeviceProxy`
         :param aproxies: attribute proxies
-        :type aproxies: :obj:`list` <:class:`PyTango.DeviceProxy`>
+        :type aproxies: :obj:`list` <:class:`tango.DeviceProxy`>
         """
-        QtCore.QThread.__init__(self)
+        OmniQThread.__init__(self)
         #: (:obj:`bool`) execute loop flag
         self.__loop = False
         #: (:obj:`bool`) execute loop flag
         self.__refreshtime = refreshtime or POLLINGINTERVAL
 
-        #: (:obj:`list` <:class:`PyTango.DeviceProxy`>)  attribute proxies
+        #: (:obj:`list` <:class:`tango.DeviceProxy`>)  attribute proxies
         self.__aproxies = aproxies or []
 
-    def run(self):
+    # @debugmethod
+    def _run(self):
         """ runner of the fetching thread
         """
         self.__loop = True
         while self.__loop:
+            # logger.debug("ATTR LOOP %s" % (self.__loop))
             try:
                 attrs = []
                 for ap in self.__aproxies:
@@ -153,10 +162,11 @@ class AttributeWatchThread(QtCore.QThread):
                 self.attrValuesSignal.emit(str(json.dumps(attrs)))
             except Exception as e:
                 logger.warning(str(e))
-            if time:
+            if time and self.__loop:
                 time.sleep(self.__refreshtime)
 
-    def isRunning(self):
+    # @debugmethod
+    def isWatching(self):
         """ is datasource source connected
 
         :returns: if datasource source connected
@@ -164,8 +174,10 @@ class AttributeWatchThread(QtCore.QThread):
         """
         return self.__loop
 
+    # @debugmethod
     def stop(self):
         """ stops loop
 
         """
         self.__loop = False
+        # logger.debug("STOP LOOP %s" % (self.__loop))
