@@ -48,6 +48,10 @@ _hidraformclass, _hidrabaseclass = uic.loadUiType(
     os.path.join(os.path.dirname(os.path.abspath(__file__)),
                  "ui", "HidraSourceWidget.ui"))
 
+_asapoformclass, _asapobaseclass = uic.loadUiType(
+    os.path.join(os.path.dirname(os.path.abspath(__file__)),
+                 "ui", "ASAPOSourceWidget.ui"))
+
 _tangoattrformclass, _tangoattrbaseclass = uic.loadUiType(
     os.path.join(os.path.dirname(os.path.abspath(__file__)),
                  "ui", "TangoAttrSourceWidget.ui"))
@@ -92,6 +96,7 @@ __all__ = [
     'NXSFileSourceWidget',
     'TinePropSourceWidget',
     'EpicsPVSourceWidget',
+    'ASAPOSourceWidget',
     # 'FixTestSourceWidget',
     'TestSourceWidget',
     'swproperties'
@@ -148,6 +153,14 @@ class SourceBaseWidget(QtGui.QWidget):
         #: (:obj:`bool`) source widget detached
         self.__detached = False
 
+    def setActive(self, active=True):
+        """ set active flag
+
+        :param active: active flag
+        :type active: :obj:`bool`
+        """
+        self.active = active
+
     @QtCore.pyqtSlot()
     def updateButton(self):
         """ update slot for test source
@@ -576,7 +589,7 @@ class HidraSourceWidget(SourceBaseWidget):
         :returns configuration: configuration string
         :rtype configuration: :obj:`str`
         """
-        return "%s %s %s" % (
+        return "%s,%s,%s" % (
             str(self._ui.serverComboBox.currentText()),
             self.__targetname,
             self.__portnumber
@@ -644,6 +657,9 @@ class HidraSourceWidget(SourceBaseWidget):
         :param configuration: configuration string
         :type configuration: :obj:`str`
         """
+        configuration = configuration.split(" ")
+        if configuration:
+            configuration = configuration[0]
         iid = self._ui.serverComboBox.findText(configuration)
         if iid == -1:
             self._ui.serverComboBox.addItem(configuration)
@@ -663,6 +679,259 @@ class HidraSourceWidget(SourceBaseWidget):
             return re.sub("[^a-zA-Z0-9_]+", "_", label)
 
 
+class ASAPOSourceWidget(SourceBaseWidget):
+
+    """ test source widget """
+
+    #: (:obj:`str`) source name
+    name = "ASAPO"
+    #: (:obj:`str`) source alias
+    alias = "asapo"
+    #: (:obj:`tuple` <:obj:`str`>) capitalized required packages
+    requires = ("ASAPO",)
+    #: (:obj:`str`) datasource class name
+    datasource = "ASAPOSource"
+
+    def __init__(self, parent=None):
+        """ constructor
+
+        :param parent: parent object
+        :type parent: :class:`pyqtgraph.QtCore.QObject`
+        """
+        SourceBaseWidget.__init__(self, parent)
+
+        self._ui = _asapoformclass()
+        self._ui.setupUi(self)
+
+        #: (:obj:`list` <:obj:`str`>) subwidget object names
+        self.widgetnames = [
+            "asapodatasourceLabel", "asapodatasourceComboBox",
+            "asapostreamLabel", "asapostreamComboBox",
+        ]
+
+        #: (:obj:`str`>) asapo server i.e. host:port
+        self.__server = ""
+        #: (:obj:`str`>) beamtime id
+        self.__beamtime = ""
+        #: (:obj:`str`>) source path
+        self.__sourcepath = ""
+        #: (:obj:`str`>) asapo token
+        self.__token = ""
+
+        #: (:obj:`list` <:obj:`str`> >) datasource list
+        self.__datasources = []
+        #: (:obj:`list` <:obj:`str`> >) asapo streams
+        self.__streams = []
+        #: (:obj:`bool`) updating flag
+        self.__updating = False
+        #: (:class:`pyqtgraph.QtCore.QMutex`) update mutex
+        self.__udmutex = QtCore.QMutex()
+
+        #: (:class:`pyqtgraph.QtCore.QMutex`) zmq datasource mutex
+        self.__mutex = QtCore.QMutex()
+
+        self._detachWidgets()
+
+        self._ui.asapodatasourceComboBox.addItems(["detector"])
+        self._ui.asapostreamComboBox.addItems(["default", "**ALL**"])
+        self._ui.asapodatasourceComboBox.currentIndexChanged.connect(
+            self.updateButton)
+        # self._connectComboBox()
+        self._ui.asapostreamComboBox.currentIndexChanged.connect(
+            self._updateStreamComboBox)
+
+    @QtCore.pyqtSlot()
+    def updateButton(self, disconnect=True):
+        """ update slot for Asapo source
+        """
+        with QtCore.QMutexLocker(self.__udmutex):
+            if not self.active or self.__updating:
+                return
+            else:
+                self.__updating = True
+        with QtCore.QMutexLocker(self.__mutex):
+            if disconnect:
+                self._ui.asapostreamComboBox.\
+                    currentIndexChanged.disconnect(
+                        self._updateStreamComboBox)
+            if not self._ui.asapostreamComboBox.count() \
+               or not self._ui.asapodatasourceComboBox.currentText() \
+               or not self.__server \
+               or not self.__token \
+               or not self.__beamtime:
+                self.buttonEnabled.emit(False)
+            else:
+                self.buttonEnabled.emit(True)
+                self.sourceLabelChanged.emit()
+            if disconnect:
+                self._ui.asapostreamComboBox.\
+                    currentIndexChanged.connect(
+                        self._updateStreamComboBox)
+        with QtCore.QMutexLocker(self.__udmutex):
+            self.__updating = False
+
+    def configuration(self):
+        """ provides configuration for the current image source
+
+        :returns configuration: configuration string
+        :rtype configuration: :obj:`str`
+        """
+        return "%s,%s,%s,%s,%s,%s" % (
+            self.__server,
+            str(self._ui.asapodatasourceComboBox.currentText()),
+            str(self._ui.asapostreamComboBox.currentText()),
+            self.__beamtime,
+            self.__sourcepath,
+            self.__token
+        )
+
+    def updateMetaData(self, asaposerver=None, asapotoken=None,
+                       asapobeamtime=None,
+                       asapodatasources=None, asapostreams=None,
+                       asaposourcepath=None,
+                       disconnect=True,
+                       **kargs):
+        """ update source input parameters
+
+        :param asaposervers asapo servers, i.e. host:port
+        :type asaposervers: :obj:`str`
+        :param asapotoken: asapo token
+        :type asapotoken: :obj:`str`
+        :param asapobeamtime: beamtime id
+        :type asapobeamtime: :obj:`str`
+        :param asapodatasources: asapo datasource names
+        :type asapodatasources: :obj:`list` <:obj:`str`> >
+        :param asapostreams: asapo stream names
+        :type asapostreams: :obj:`list` <:obj:`str`> >
+        :param asaposourcepath: source path
+        :type asaposourcepath: :obj:`str`
+        :param disconnect: disconnect on update
+        :type disconnect: :obj:`bool`
+        :param kargs:  source widget input parameter dictionary
+        :type kargs: :obj:`dict` < :obj:`str`, :obj:`any`>
+        """
+        if disconnect:
+            with QtCore.QMutexLocker(self.__mutex):
+                self._ui.asapostreamComboBox.currentIndexChanged.\
+                    disconnect(self._updateStreamComboBox)
+        text = None
+        if isinstance(asapodatasources, list):
+            self._ui.asapodatasourceComboBox.currentIndexChanged.disconnect(
+                self.updateButton)
+            self.__datasources = asapodatasources
+            for i in reversed(
+                    range(0, self._ui.asapodatasourceComboBox.count())):
+                self._ui.asapodatasourceComboBox.removeItem(i)
+            if not asapodatasources:
+                self._ui.asapodatasourceComboBox.addItems(["detector"])
+            self._ui.asapodatasourceComboBox.addItems(self.__datasources)
+            self._ui.asapodatasourceComboBox.currentIndexChanged.connect(
+                self.updateButton)
+            self._ui.asapodatasourceComboBox.setCurrentIndex(0)
+        if asaposerver is not None:
+            self.__server = asaposerver
+        if asapotoken is not None:
+            self.__token = asapotoken
+        if asapobeamtime is not None:
+            self.__beamtime = asapobeamtime
+        if asaposourcepath is not None:
+            self.__sourcepath = asaposourcepath
+        updatecombo = False
+        if isinstance(asapostreams, list):
+            with QtCore.QMutexLocker(self.__mutex):
+                text = str(
+                    self._ui.asapostreamComboBox.currentText())
+            if not text or text not in asapostreams:
+                if text not in ["default", "**ALL**"]:
+                    text = None
+            self.__streams = asapostreams
+            updatecombo = True
+        if updatecombo is True:
+            with QtCore.QMutexLocker(self.__mutex):
+                for i in reversed(
+                        range(0, self._ui.asapostreamComboBox.count())):
+                    self._ui.asapostreamComboBox.removeItem(i)
+                if not self.__streams or \
+                   "default" not in self.__streams:
+                    self._ui.asapostreamComboBox.addItem("default")
+                self._ui.asapostreamComboBox.addItems(
+                    sorted(self.__streams))
+                if not self.__streams or \
+                   "**ALL**" not in self.__streams:
+                    self._ui.asapostreamComboBox.addItem("**ALL**")
+                if text:
+                    tid = self._ui.asapostreamComboBox.findText(text)
+                    if tid > -1:
+                        self._ui.asapostreamComboBox.setCurrentIndex(tid)
+        if disconnect:
+            self.updateButton(disconnect=False)
+            with QtCore.QMutexLocker(self.__mutex):
+                self._ui.asapostreamComboBox.currentIndexChanged.connect(
+                    self._updateStreamComboBox)
+        if updatecombo is True and text is None:
+            self._updateStreamComboBox()
+        self.sourceLabelChanged.emit()
+
+    @QtCore.pyqtSlot()
+    def _updateStreamComboBox(self):
+        """ update ASAPO substream combobox
+        """
+        disconnected = False
+        if self._connected:
+            disconnected = True
+            self.sourceStateChanged.emit(0)
+        self.updateButton()
+        if disconnected:
+            self.sourceStateChanged.emit(-1)
+
+    def connectWidget(self):
+        """ connects widget
+        """
+        self._connected = True
+        self._ui.asapodatasourceComboBox.setEnabled(False)
+
+    def disconnectWidget(self):
+        """ disconnects widget
+        """
+        self._connected = False
+        self._ui.asapodatasourceComboBox.setEnabled(True)
+
+    def configure(self, configuration):
+        """ set configuration for the current image source
+
+        :param configuration: configuration string
+        :type configuration: :obj:`str`
+        """
+        cnflst = configuration.split(",")
+        datasource = cnflst[0] if cnflst else ""
+        stream = ""
+        if len(cnflst) > 1:
+            stream = cnflst[1]
+            if not stream:
+                stream = "default"
+        iid = self._ui.asapodatasourceComboBox.findText(datasource)
+        if iid == -1:
+            self._ui.asapodatasourceComboBox.addItem(datasource)
+            iid = self._ui.asapodatasourceComboBox.findText(datasource)
+        self._ui.asapodatasourceComboBox.setCurrentIndex(iid)
+
+        if stream:
+            iid = self._ui.asapostreamComboBox.findText(stream)
+            if iid == -1:
+                self._ui.asapostreamComboBox.addItem(stream)
+                iid = self._ui.asapostreamComboBox.findText(stream)
+            self._ui.asapostreamComboBox.setCurrentIndex(iid)
+
+    def label(self):
+        """ return a label of the current detector
+
+        :return: label of the current detector
+        :rtype: :obj:`str`
+        """
+        label = str(self._ui.asapostreamComboBox.currentText()).strip()
+        return re.sub("[^a-zA-Z0-9_]+", "_", label)
+
+
 class TangoAttrSourceWidget(SourceBaseWidget):
 
     """ test source widget """
@@ -672,7 +941,7 @@ class TangoAttrSourceWidget(SourceBaseWidget):
     #: (:obj:`str`) source alias
     alias = "tangoattr"
     #: (:obj:`tuple` <:obj:`str`>) capitalized required packages
-    requires = ("PYTANGO",)
+    requires = ("TANGO",)
     #: (:obj:`str`) datasource class name
     datasource = "TangoAttrSource"
 
@@ -980,7 +1249,7 @@ class TangoEventsSourceWidget(SourceBaseWidget):
     #: (:obj:`str`) source alias
     alias = "tangoevents"
     #: (:obj:`tuple` <:obj:`str`>) capitalized required packages
-    requires = ("PYTANGO",)
+    requires = ("TANGO",)
     #: (:obj:`str`) datasource class name
     datasource = "TangoEventsSource"
 
@@ -1132,7 +1401,7 @@ class TangoFileSourceWidget(SourceBaseWidget):
     #: (:obj:`str`) source alias
     alias = "tangofile"
     #: (:obj:`tuple` <:obj:`str`>) capitalized required packages
-    requires = ("PYTANGO",)
+    requires = ("TANGO",)
     #: (:obj:`str`) datasource class name
     datasource = "TangoFileSource"
 
@@ -1169,6 +1438,11 @@ class TangoFileSourceWidget(SourceBaseWidget):
         #: (:obj:`list` <:obj:`str`>) user dir tango attributes
         self.__userdirattrs = []
 
+        #: (:obj:`bool`) nexus file source keeps the file open
+        self.__nxsopen = False
+        #: (:obj:`bool`) nexus file source starts from the last image
+        self.__nxslast = False
+
         self._detachWidgets()
 
         #: (:obj:`str`) default file tip
@@ -1216,7 +1490,7 @@ class TangoFileSourceWidget(SourceBaseWidget):
         """
         if not self.active:
             return
-        fattr, dattr, dt = self.__configuration()
+        fattr, dattr, dt, no, nl = self.__configuration()
         if not fattr:
             self.buttonEnabled.emit(False)
         else:
@@ -1238,7 +1512,7 @@ class TangoFileSourceWidget(SourceBaseWidget):
         if dattr in self.__tangodirattrs.keys():
             dattr = str(self.__tangodirattrs[dattr]).strip()
         dt = self.__dirtrans
-        return (fattr, dattr, dt)
+        return (fattr, dattr, dt, self.__nxsopen, self.__nxslast)
 
     def configuration(self):
         """ provides configuration for the current image source
@@ -1246,10 +1520,10 @@ class TangoFileSourceWidget(SourceBaseWidget):
         :returns configuration: configuration string
         :rtype configuration: :obj:`str`
         """
-        return "%s,%s,%s" % self.__configuration()
+        return "%s,%s,%s,%s,%s" % self.__configuration()
 
     def updateMetaData(self, tangofileattrs=None, tangodirattrs=None,
-                       dirtrans=None, **kargs):
+                       dirtrans=None, nxsopen=None, nxslast=None, **kargs):
         """ update source input parameters
 
         :param tangofileattrs: json dictionary with
@@ -1261,6 +1535,10 @@ class TangoFileSourceWidget(SourceBaseWidget):
         :param dirtrans: json dictionary with directory
                          and file name translation
         :type dirtrans: :obj:`str`
+        :param nxsopen: nexus file source keeps the file open
+        :type nxsopen: :obj:`bool`
+        :param nxslast: nexus file source starts from the last image
+        :type nxslast: :obj:`bool`
         :param kargs:  source widget input parameter dictionary
         :type kargs: :obj:`dict` < :obj:`str`, :obj:`any`>
         """
@@ -1276,6 +1554,10 @@ class TangoFileSourceWidget(SourceBaseWidget):
                 self.__userdirattrs)
         if dirtrans is not None:
             self.__dirtrans = dirtrans
+        if nxsopen is not None:
+            self.__nxsopen = nxsopen
+        if nxslast is not None:
+            self.__nxslast = nxslast
         self.sourceLabelChanged.emit()
 
     @QtCore.pyqtSlot()
@@ -1605,7 +1887,8 @@ class NXSFileSourceWidget(SourceBaseWidget):
         self.widgetnames = [
             "nxsFileLabel", "nxsFileLineEdit",
             "nxsFieldLabel", "nxsFieldLineEdit",
-            "nxsDimLabel", "nxsDimSpinBox"
+            "nxsDimLabel", "nxsDimSpinBox",
+            "nxsFrameLabel", "nxsFrameSpinBox"
         ]
         #: (:obj:`bool`) nexus file source keeps the file open
         self.__nxsopen = False
@@ -1618,10 +1901,24 @@ class NXSFileSourceWidget(SourceBaseWidget):
 
         self._ui.nxsFileLineEdit.textEdited.connect(self.updateButton)
         self._ui.nxsFieldLineEdit.textEdited.connect(self.updateButton)
+        self._ui.nxsFrameSpinBox.valueChanged.connect(
+            self._updateFrameSpinBox)
         self._ui.nxsDimSpinBox.valueChanged.connect(self.updateButton)
         self._ui.nxsFileLineEdit.installEventFilter(self)
         self._ui.nxsFieldLineEdit.installEventFilter(self)
 
+    @QtCore.pyqtSlot()
+    def _updateFrameSpinBox(self):
+        """ update nexus frame combobox
+        """
+        disconnected = False
+        if self._connected:
+            disconnected = True
+            self.sourceStateChanged.emit(0)
+        self.updateButton()
+        if disconnected:
+            self.sourceStateChanged.emit(-1)
+
     def eventFilter(self, obj, event):
         """ event filter
 
@@ -1681,7 +1978,7 @@ class NXSFileSourceWidget(SourceBaseWidget):
         """
         if not self.active:
             return
-        nfl, nfd, nsb, nxsopen, nxslast = self.__configuration()
+        nfl, nfd, nsb, nfm, nxsopen, nxslast = self.__configuration()
         if not nfl or not nfd:
             self.buttonEnabled.emit(False)
         else:
@@ -1696,8 +1993,9 @@ class NXSFileSourceWidget(SourceBaseWidget):
         """
         nfl = str(self._ui.nxsFileLineEdit.text()).strip()
         nfd = str(self._ui.nxsFieldLineEdit.text()).strip()
+        nfm = int(self._ui.nxsFrameSpinBox.value())
         nsb = int(self._ui.nxsDimSpinBox.value())
-        return (nfl, nfd, nsb, self.__nxsopen, self.__nxslast)
+        return (nfl, nfd, nfm, nsb, self.__nxsopen, self.__nxslast)
 
     def configuration(self):
         """ provides configuration for the current image source
@@ -1705,7 +2003,7 @@ class NXSFileSourceWidget(SourceBaseWidget):
         :returns configuration: configuration string
         :rtype configuration: :obj:`str`
         """
-        return "%s,%s,%s,%s,%s" % self.__configuration()
+        return "%s,%s,%s,%s,%s,%s" % self.__configuration()
 
     def connectWidget(self):
         """ connects widget
@@ -1723,7 +2021,7 @@ class NXSFileSourceWidget(SourceBaseWidget):
         self._ui.nxsFieldLineEdit.setReadOnly(False)
         self._ui.nxsDimSpinBox.setEnabled(True)
 
-    def updateMetaData(self, nxsopen=None, nxslast=None,  **kargs):
+    def updateMetaData(self, nxsopen=None, nxslast=None, **kargs):
         """ update source input parameters
 
         :param nxsopen: nexus file source keeps the file open
@@ -1764,9 +2062,15 @@ class NXSFileSourceWidget(SourceBaseWidget):
         except Exception:
             growcnf = 0
 
+        try:
+            nfm = int(cnflst[2].replace("m", "-"))
+        except Exception:
+            nfm = -1
+
         self._ui.nxsFileLineEdit.setText(filecnf)
         self._ui.nxsFieldLineEdit.setText(fieldcnf)
         self._ui.nxsDimSpinBox.setValue(growcnf)
+        self._ui.nxsFrameSpinBox.setValue(nfm)
         self.updateButton()
 
     def label(self):
@@ -1789,7 +2093,7 @@ class ZMQSourceWidget(SourceBaseWidget):
     #: (:obj:`str`) source name
     name = "ZMQ Stream"
     #: (:obj:`str`) source alias
-    alias = "zmqsource"
+    alias = "zmq"
     #: (:obj:`str`) datasource class name
     datasource = "ZMQSource"
 
@@ -1823,6 +2127,10 @@ class ZMQSourceWidget(SourceBaseWidget):
 
         #: (:class:`pyqtgraph.QtCore.QMutex`) zmq datasource mutex
         self.__mutex = QtCore.QMutex()
+        #: (:class:`pyqtgraph.QtCore.QMutex`) update mutex
+        self.__udmutex = QtCore.QMutex()
+        #: (:obj:`bool`) updating flag
+        self.__updating = False
 
         self._detachWidgets()
 
@@ -1856,8 +2164,11 @@ class ZMQSourceWidget(SourceBaseWidget):
     def updateButton(self, disconnect=True):
         """ update slot for ZMQ source
         """
-        if not self.active:
-            return
+        with QtCore.QMutexLocker(self.__udmutex):
+            if not self.active or self.__updating:
+                return
+            else:
+                self.__updating = True
         with QtCore.QMutexLocker(self.__mutex):
             if disconnect:
                 self._ui.pickleTopicComboBox.currentIndexChanged.disconnect(
@@ -1871,6 +2182,8 @@ class ZMQSourceWidget(SourceBaseWidget):
             if disconnect:
                 self._ui.pickleTopicComboBox.currentIndexChanged.connect(
                     self._updateZMQComboBox)
+        with QtCore.QMutexLocker(self.__udmutex):
+            self.__updating = False
 
     def configuration(self):
         """ provides configuration for the current image source
@@ -1962,7 +2275,8 @@ class ZMQSourceWidget(SourceBaseWidget):
                 text = str(self._ui.pickleTopicComboBox.currentText())
             if isinstance(datasources, list):
                 if not text or text not in datasources:
-                    text = None
+                    if text != "**ALL**":
+                        text = None
                 self.__zmqtopics = datasources
         if updatecombo is True:
             with QtCore.QMutexLocker(self.__mutex):
@@ -1980,6 +2294,8 @@ class ZMQSourceWidget(SourceBaseWidget):
             with QtCore.QMutexLocker(self.__mutex):
                 self._ui.pickleTopicComboBox.currentIndexChanged.connect(
                     self._updateZMQComboBox)
+        if updatecombo is True and text is None:
+            self._updateZMQComboBox()
         self.sourceLabelChanged.emit()
 
     def connectWidget(self):
@@ -2016,9 +2332,13 @@ class ZMQSourceWidget(SourceBaseWidget):
         :param configuration: configuration string
         :type configuration: :obj:`str`
         """
-        cnflst = configuration.split(",")
+        cnflst = configuration.replace("/", ",").split(",")
         srvcnf = cnflst[0] if cnflst else ""
-        topiccnf = cnflst[1] if len(cnflst) > 1 else ""
+        topiccnf = ""
+        if len(cnflst) > 1:
+            topiccnf = cnflst[1]
+            if not topiccnf:
+                topiccnf = "**ALL**"
 
         iid = self._ui.pickleComboBox.findText(srvcnf)
         if iid == -1:
